@@ -1,10 +1,14 @@
 #!/bin/sh
+set -eu
 
 #
 # Simple script to repopulate the 'doc' tree from
 # the mdoc man pages stored in each project.
 #
 
+script_dir=`dirname $0`
+cd "$script_dir"
+
 # Collect list of man pages, relative to my subdirs
 test -d man || mkdir man
 cd man
@@ -80,7 +84,7 @@ for f in $MANPAGES; do
     outname="`basename $f`.html"
     echo >> Makefile
     echo $outname: $f >> Makefile
-    echo "	groff -mdoc2html $f > $outname" >> Makefile
+    echo "	groff -mdoc -T html $f > $outname" >> Makefile
     all="$all $outname"
 done
 echo $all >>Makefile
@@ -113,5 +117,5 @@ cd ..
 (cd pdf && make)
 # Format all of the manpages to HTML
 (cd html && make)
-# Format all of the manpages to Google Wiki syntax
+# Format all of the manpages to wiki syntax
 (cd wiki && make)
