@@ -25,7 +25,7 @@
 #define	REG_BASIC 0
 #endif
 
-#include "err.h"
+#include "lafe_err.h"
 
 struct subst_rule {
 	struct subst_rule *next;
@@ -229,12 +229,15 @@ apply_substitution(struct bsdtar *bsdtar, const char *name, char **result,
 
 		if (rule->from_begin && *result) {
 			realloc_strcat(result, name);
+			if (buffer) buffer[0] = 0;
 			realloc_strcat(&buffer, *result);
 			name = buffer;
 			(*result)[0] = 0;
 		}
 
-		while (1) {
+		char isEnd = 0;
+		do {
+            isEnd = *name == '\0';
 			if (regexec(&rule->re, name, 10, matches, 0))
 				break;
 
@@ -289,12 +292,15 @@ apply_substitution(struct bsdtar *bsdtar, const char *name, char **result,
 			}
 
 			realloc_strcat(result, rule->result + j);
-
-			name += matches[0].rm_eo;
-
-			if (!rule->global)
-				break;
-		}
+			if (matches[0].rm_eo > 0) {
+                name += matches[0].rm_eo;
+            } else {
+                // We skip a character because the match is 0-length
+                // so we need to add it to the output
+                realloc_strncat(result, name, 1);
+                name += 1;
+            }
+		} while (rule->global && !isEnd); // Testing one step after because sed et al. run 0-length patterns a last time on the empty string at the end
 	}
 
 	if (got_match)
